Class: Google::Cloud::Memorystore::V1::AddTokenAuthUserRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1/memorystore.rb

Overview

Request message for AddTokenAuthUser.

Instance Attribute Summary collapse

Instance Attribute Details

#instance::String

Returns Required. The instance resource that this token auth user will be added for. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The instance resource that this token auth user will be added for. Format: projects/{project}/locations/{location}/instances/{instance}



1598
1599
1600
1601
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1598

class AddTokenAuthUserRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#token_auth_user::String

Returns Required. The name of the token auth user to add.

Returns:

  • (::String)

    Required. The name of the token auth user to add.



1598
1599
1600
1601
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1598

class AddTokenAuthUserRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end