Class: Google::Cloud::Memorystore::V1::AutomatedBackupConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1/memorystore.rb

Overview

The automated backup config for an instance.

Defined Under Namespace

Modules: AutomatedBackupMode Classes: FixedFrequencySchedule

Instance Attribute Summary collapse

Instance Attribute Details

#automated_backup_mode::Google::Cloud::Memorystore::V1::AutomatedBackupConfig::AutomatedBackupMode

Returns Optional. The automated backup mode. If the mode is disabled, the other fields will be ignored.

Returns:



425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 425

class AutomatedBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This schedule allows the backup to be triggered at a fixed frequency
  # (currently only daily is supported).
  # @!attribute [rw] start_time
  #   @return [::Google::Type::TimeOfDay]
  #     Required. The start time of every automated backup in UTC. It must be set
  #     to the start of an hour. This field is required.
  class FixedFrequencySchedule
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The automated backup mode.
  module AutomatedBackupMode
    # Default value. Automated backup config is not specified.
    AUTOMATED_BACKUP_MODE_UNSPECIFIED = 0

    # Automated backup config disabled.
    DISABLED = 1

    # Automated backup config enabled.
    ENABLED = 2
  end
end

#fixed_frequency_schedule::Google::Cloud::Memorystore::V1::AutomatedBackupConfig::FixedFrequencySchedule

Returns Optional. Trigger automated backups at a fixed frequency.

Returns:



425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 425

class AutomatedBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This schedule allows the backup to be triggered at a fixed frequency
  # (currently only daily is supported).
  # @!attribute [rw] start_time
  #   @return [::Google::Type::TimeOfDay]
  #     Required. The start time of every automated backup in UTC. It must be set
  #     to the start of an hour. This field is required.
  class FixedFrequencySchedule
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The automated backup mode.
  module AutomatedBackupMode
    # Default value. Automated backup config is not specified.
    AUTOMATED_BACKUP_MODE_UNSPECIFIED = 0

    # Automated backup config disabled.
    DISABLED = 1

    # Automated backup config enabled.
    ENABLED = 2
  end
end

#retention::Google::Protobuf::Duration

Returns Optional. How long to keep automated backups before the backups are deleted. The value should be between 1 day and 365 days. If not specified, the default value is 35 days.

Returns:

  • (::Google::Protobuf::Duration)

    Optional. How long to keep automated backups before the backups are deleted. The value should be between 1 day and 365 days. If not specified, the default value is 35 days.



425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 425

class AutomatedBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This schedule allows the backup to be triggered at a fixed frequency
  # (currently only daily is supported).
  # @!attribute [rw] start_time
  #   @return [::Google::Type::TimeOfDay]
  #     Required. The start time of every automated backup in UTC. It must be set
  #     to the start of an hour. This field is required.
  class FixedFrequencySchedule
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The automated backup mode.
  module AutomatedBackupMode
    # Default value. Automated backup config is not specified.
    AUTOMATED_BACKUP_MODE_UNSPECIFIED = 0

    # Automated backup config disabled.
    DISABLED = 1

    # Automated backup config enabled.
    ENABLED = 2
  end
end