Class: Google::Cloud::Memorystore::V1::DeleteAuthTokenRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1/memorystore.rb

Overview

Request message for DeleteAuthToken.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the token auth user resource that this token will be deleted from. Format: projects/{project}/locations/{location}/instances/{instance}/tokenAuthUsers/{token_auth_user}/authTokens/{name}.

Returns:

  • (::String)

    Required. The name of the token auth user resource that this token will be deleted from. Format: projects/{project}/locations/{location}/instances/{instance}/tokenAuthUsers/{token_auth_user}/authTokens/{name}



1653
1654
1655
1656
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1653

class DeleteAuthTokenRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end