Class: Google::Cloud::Memorystore::V1::FinishMigrationRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1/memorystore.rb

Overview

Request for FinishMigration.

Instance Attribute Summary collapse

Instance Attribute Details

#force::Boolean

Returns Optional. By default, the FinishMigration operation ensures the target replication offset to catch up to the source offset as of the time of the call. Set this field to true to bypass this offset verification check.

Returns:

  • (::Boolean)

    Optional. By default, the FinishMigration operation ensures the target replication offset to catch up to the source offset as of the time of the call. Set this field to true to bypass this offset verification check.



442
443
444
445
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 442

class FinishMigrationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The resource name of the instance to finalize migration on. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The resource name of the instance to finalize migration on. Format: projects/{project}/locations/{location}/instances/{instance}



442
443
444
445
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 442

class FinishMigrationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end