Class: Google::Cloud::Memorystore::V1::MigrationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1/memorystore.rb

Overview

Configuration for the migration of an instance.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#force_finish_migration::Boolean (readonly)

Returns Output only. Represents a boolean flag to force migration finalization without offset catch up validation between source and target before stopping replication.

Returns:

  • (::Boolean)

    Output only. Represents a boolean flag to force migration finalization without offset catch up validation between source and target before stopping replication.



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 488

class MigrationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Migration state of the instance.
  # New values may be added in the future.
  module State
    # Instance has no migration related activity. This is the initial state.
    STATE_UNSPECIFIED = 0

    # Instance is not currently migrating. The instance underwent a migration
    # attempt that failed, and the subsequent rollback was successful. The
    # instance is now ready for a new migration attempt if desired.
    ROLLED_BACK = 1

    # Indicates a previous migration attempt failed. The high-level instance
    # state will be `MIGRATING`. The instance is not ready for a new migration
    # attempt. Rollback is in progress to restore the instance to its original
    # state. The instance will remain in this state until rollback is
    # successful.
    ROLLING_BACK = 5

    # Instance is in the process of migration. Instance has established
    # successful replication and is ready for cutover.
    REPLICATION_ESTABLISHED = 6

    # Instance is successfully migrated.
    MIGRATED = 4
  end
end

#self_managed_source::Google::Cloud::Memorystore::V1::SelfManagedSource (readonly)

Returns Output only. Configuration for migrating from a self-managed Valkey/Redis instance.

Returns:



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 488

class MigrationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Migration state of the instance.
  # New values may be added in the future.
  module State
    # Instance has no migration related activity. This is the initial state.
    STATE_UNSPECIFIED = 0

    # Instance is not currently migrating. The instance underwent a migration
    # attempt that failed, and the subsequent rollback was successful. The
    # instance is now ready for a new migration attempt if desired.
    ROLLED_BACK = 1

    # Indicates a previous migration attempt failed. The high-level instance
    # state will be `MIGRATING`. The instance is not ready for a new migration
    # attempt. Rollback is in progress to restore the instance to its original
    # state. The instance will remain in this state until rollback is
    # successful.
    ROLLING_BACK = 5

    # Instance is in the process of migration. Instance has established
    # successful replication and is ready for cutover.
    REPLICATION_ESTABLISHED = 6

    # Instance is successfully migrated.
    MIGRATED = 4
  end
end

#state::Google::Cloud::Memorystore::V1::MigrationConfig::State (readonly)

Returns Output only. Migration state of the instance.

Returns:



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 488

class MigrationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Migration state of the instance.
  # New values may be added in the future.
  module State
    # Instance has no migration related activity. This is the initial state.
    STATE_UNSPECIFIED = 0

    # Instance is not currently migrating. The instance underwent a migration
    # attempt that failed, and the subsequent rollback was successful. The
    # instance is now ready for a new migration attempt if desired.
    ROLLED_BACK = 1

    # Indicates a previous migration attempt failed. The high-level instance
    # state will be `MIGRATING`. The instance is not ready for a new migration
    # attempt. Rollback is in progress to restore the instance to its original
    # state. The instance will remain in this state until rollback is
    # successful.
    ROLLING_BACK = 5

    # Instance is in the process of migration. Instance has established
    # successful replication and is ready for cutover.
    REPLICATION_ESTABLISHED = 6

    # Instance is successfully migrated.
    MIGRATED = 4
  end
end