Module: Google::Cloud::Memorystore::V1::MigrationConfig::State

Defined in:
proto_docs/google/cloud/memorystore/v1/memorystore.rb

Overview

Migration state of the instance. New values may be added in the future.

Constant Summary collapse

STATE_UNSPECIFIED =

Instance has no migration related activity. This is the initial state.

0
ROLLED_BACK =

Instance is not currently migrating. The instance underwent a migration attempt that failed, and the subsequent rollback was successful. The instance is now ready for a new migration attempt if desired.

1
ROLLING_BACK =

Indicates a previous migration attempt failed. The high-level instance state will be MIGRATING. The instance is not ready for a new migration attempt. Rollback is in progress to restore the instance to its original state. The instance will remain in this state until rollback is successful.

5
REPLICATION_ESTABLISHED =

Instance is in the process of migration. Instance has established successful replication and is ready for cutover.

6
MIGRATED =

Instance is successfully migrated.

4