Class: Google::Cloud::Memorystore::V1::PscConnection
- Inherits:
-
Object
- Object
- Google::Cloud::Memorystore::V1::PscConnection
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/memorystore/v1/memorystore.rb
Overview
User created Psc connection configuration.
Instance Attribute Summary collapse
-
#connection_type ⇒ ::Google::Cloud::Memorystore::V1::ConnectionType
readonly
Output only.
-
#forwarding_rule ⇒ ::String
Required.
-
#ip_address ⇒ ::String
Required.
-
#network ⇒ ::String
Required.
-
#port ⇒ ::Integer
Optional.
-
#project_id ⇒ ::String
readonly
Output only.
-
#psc_connection_id ⇒ ::String
Required.
-
#psc_connection_status ⇒ ::Google::Cloud::Memorystore::V1::PscConnectionStatus
readonly
Output only.
-
#service_attachment ⇒ ::String
Required.
Instance Attribute Details
#connection_type ⇒ ::Google::Cloud::Memorystore::V1::ConnectionType (readonly)
Returns Output only. Type of the PSC connection.
922 923 924 925 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 922 class PscConnection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#forwarding_rule ⇒ ::String
Returns Required. The URI of the consumer side forwarding rule. Format: projects/{project}/regions/{region}/forwardingRules/{forwarding_rule}.
922 923 924 925 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 922 class PscConnection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ip_address ⇒ ::String
Returns Required. The IP allocated on the consumer network for the PSC forwarding rule.
922 923 924 925 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 922 class PscConnection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#network ⇒ ::String
Returns Required. The consumer network where the IP address resides, in the form of projects/{project_id}/global/networks/{network_name}.
922 923 924 925 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 922 class PscConnection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#port ⇒ ::Integer
Returns Optional. port will only be set for Primary/Reader or Discovery endpoint.
922 923 924 925 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 922 class PscConnection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project_id ⇒ ::String (readonly)
Returns Output only. The consumer project_id where the forwarding rule is created from.
922 923 924 925 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 922 class PscConnection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#psc_connection_id ⇒ ::String
Returns Required. The PSC connection id of the forwarding rule connected to the service attachment.
922 923 924 925 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 922 class PscConnection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#psc_connection_status ⇒ ::Google::Cloud::Memorystore::V1::PscConnectionStatus (readonly)
Returns Output only. The status of the PSC connection: whether a connection exists and ACTIVE or it no longer exists. Please note that this value is updated periodically. Please use Private Service Connect APIs for the latest status.
922 923 924 925 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 922 class PscConnection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#service_attachment ⇒ ::String
Returns Required. The service attachment which is the target of the PSC connection, in the form of projects/{project-id}/regions/{region}/serviceAttachments/{service-attachment-id}.
922 923 924 925 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 922 class PscConnection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |