Class: Google::Cloud::Memorystore::V1::StartMigrationRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1/memorystore.rb

Overview

Request for StartMigration.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The resource name of the instance to start migration on. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The resource name of the instance to start migration on. Format: projects/{project}/locations/{location}/instances/{instance}



427
428
429
430
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 427

class StartMigrationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#self_managed_source::Google::Cloud::Memorystore::V1::SelfManagedSource

Returns Required. Configuration for migrating from a self-managed Valkey/Redis instance.

Returns:



427
428
429
430
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 427

class StartMigrationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end