Class: Google::Cloud::Memorystore::V1::UpdateInstanceRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1/memorystore.rb

Overview

Request message for [UpdateInstance][].

Instance Attribute Summary collapse

Instance Attribute Details

#instance::Google::Cloud::Memorystore::V1::Instance

Returns Required. The instance to update.

Returns:



1106
1107
1108
1109
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1106

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



1106
1107
1108
1109
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1106

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. The list of fields to be updated on the instance. At least one field must be specified.

Returns:



1106
1107
1108
1109
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1106

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end