Class: Google::Cloud::Memorystore::V1::ZoneDistributionConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1/memorystore.rb

Overview

Zone distribution configuration for allocation of instance resources.

Defined Under Namespace

Modules: ZoneDistributionMode

Instance Attribute Summary collapse

Instance Attribute Details

#mode::Google::Cloud::Memorystore::V1::ZoneDistributionConfig::ZoneDistributionMode

Returns Optional. Current zone distribution mode. Defaults to MULTI_ZONE.

Returns:



943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 943

class ZoneDistributionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible zone distribution modes.
  module ZoneDistributionMode
    # Not Set. Default: MULTI_ZONE
    ZONE_DISTRIBUTION_MODE_UNSPECIFIED = 0

    # Distribute resources across 3 zones picked at random within the
    # region.
    MULTI_ZONE = 1

    # Provision resources in a single zone. Zone field must be specified.
    SINGLE_ZONE = 2
  end
end

#zone::String

Returns Optional. Defines zone where all resources will be allocated with SINGLE_ZONE mode. Ignored for MULTI_ZONE mode.

Returns:

  • (::String)

    Optional. Defines zone where all resources will be allocated with SINGLE_ZONE mode. Ignored for MULTI_ZONE mode.



943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 943

class ZoneDistributionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible zone distribution modes.
  module ZoneDistributionMode
    # Not Set. Default: MULTI_ZONE
    ZONE_DISTRIBUTION_MODE_UNSPECIFIED = 0

    # Distribute resources across 3 zones picked at random within the
    # region.
    MULTI_ZONE = 1

    # Provision resources in a single zone. Zone field must be specified.
    SINGLE_ZONE = 2
  end
end