Class: Google::Cloud::Memorystore::V1::Backup
- Inherits:
-
Object
- Object
- Google::Cloud::Memorystore::V1::Backup
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/memorystore/v1/memorystore.rb
Overview
Backup of an instance.
Defined Under Namespace
Modules: BackupType, State
Instance Attribute Summary collapse
-
#backup_files ⇒ ::Array<::Google::Cloud::Memorystore::V1::BackupFile>
readonly
Output only.
-
#backup_type ⇒ ::Google::Cloud::Memorystore::V1::Backup::BackupType
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#encryption_info ⇒ ::Google::Cloud::Memorystore::V1::EncryptionInfo
readonly
Output only.
-
#engine_version ⇒ ::String
readonly
Output only.
-
#expire_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#instance ⇒ ::String
readonly
Output only.
-
#instance_uid ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#node_type ⇒ ::Google::Cloud::Memorystore::V1::Instance::NodeType
readonly
Output only.
-
#replica_count ⇒ ::Integer
readonly
Output only.
-
#shard_count ⇒ ::Integer
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Memorystore::V1::Backup::State
readonly
Output only.
-
#total_size_bytes ⇒ ::Integer
readonly
Output only.
-
#uid ⇒ ::String
readonly
Output only.
Instance Attribute Details
#backup_files ⇒ ::Array<::Google::Cloud::Memorystore::V1::BackupFile> (readonly)
Returns Output only. List of backup files of the backup.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 538 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#backup_type ⇒ ::Google::Cloud::Memorystore::V1::Backup::BackupType (readonly)
Returns Output only. Type of the backup.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 538 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the backup was created.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 538 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#encryption_info ⇒ ::Google::Cloud::Memorystore::V1::EncryptionInfo (readonly)
Returns Output only. Encryption information of the backup.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 538 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#engine_version ⇒ ::String (readonly)
Returns Output only. valkey-7.5/valkey-8.0, etc.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 538 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#expire_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the backup will expire.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 538 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#instance ⇒ ::String (readonly)
Returns Output only. Instance resource path of this backup.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 538 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#instance_uid ⇒ ::String (readonly)
Returns Output only. Instance uid of this backup.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 538 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#name ⇒ ::String
Returns Identifier. Full resource path of the backup. the last part of the name is the backup id with the following format: [YYYYMMDDHHMMSS]_[Shorted Instance UID] OR customer specified while backup instance. Example: 20240515123000_1234.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 538 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#node_type ⇒ ::Google::Cloud::Memorystore::V1::Instance::NodeType (readonly)
Returns Output only. Node type of the instance.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 538 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#replica_count ⇒ ::Integer (readonly)
Returns Output only. Number of replicas for the instance.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 538 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#shard_count ⇒ ::Integer (readonly)
Returns Output only. Number of shards for the instance.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 538 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#state ⇒ ::Google::Cloud::Memorystore::V1::Backup::State (readonly)
Returns Output only. State of the backup.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 538 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#total_size_bytes ⇒ ::Integer (readonly)
Returns Output only. Total size of the backup in bytes.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 538 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#uid ⇒ ::String (readonly)
Returns Output only. System assigned unique identifier of the backup.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 538 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |