Class: Google::Cloud::Memorystore::V1::EncryptionInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Memorystore::V1::EncryptionInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/memorystore/v1/memorystore.rb
Overview
EncryptionInfo describes the encryption information of a cluster.
Defined Under Namespace
Modules: KmsKeyState, Type
Instance Attribute Summary collapse
-
#encryption_type ⇒ ::Google::Cloud::Memorystore::V1::EncryptionInfo::Type
readonly
Output only.
-
#kms_key_primary_state ⇒ ::Google::Cloud::Memorystore::V1::EncryptionInfo::KmsKeyState
readonly
Output only.
-
#kms_key_versions ⇒ ::Array<::String>
readonly
Output only.
-
#last_update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#encryption_type ⇒ ::Google::Cloud::Memorystore::V1::EncryptionInfo::Type (readonly)
Returns Output only. Type of encryption.
1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1780 class EncryptionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible encryption types. module Type # Encryption type not specified. Defaults to GOOGLE_DEFAULT_ENCRYPTION. TYPE_UNSPECIFIED = 0 # The data is encrypted at rest with a key that is fully managed by Google. # No key version will be populated. This is the default state. GOOGLE_DEFAULT_ENCRYPTION = 1 # The data is encrypted at rest with a key that is managed by the customer. # KMS key versions will be populated. CUSTOMER_MANAGED_ENCRYPTION = 2 end # The state of the KMS key perceived by the system. Refer to the public # documentation for the impact of each state. module KmsKeyState # The default value. This value is unused. KMS_KEY_STATE_UNSPECIFIED = 0 # The KMS key is enabled and correctly configured. ENABLED = 1 # Permission denied on the KMS key. PERMISSION_DENIED = 2 # The KMS key is disabled. DISABLED = 3 # The KMS key is destroyed. DESTROYED = 4 # The KMS key is scheduled to be destroyed. DESTROY_SCHEDULED = 5 # The EKM key is unreachable. EKM_KEY_UNREACHABLE_DETECTED = 6 # Billing is disabled for the project. BILLING_DISABLED = 7 # All other unknown failures. UNKNOWN_FAILURE = 8 end end |
#kms_key_primary_state ⇒ ::Google::Cloud::Memorystore::V1::EncryptionInfo::KmsKeyState (readonly)
Returns Output only. The state of the primary version of the KMS key perceived by the system. This field is not populated in backups.
1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1780 class EncryptionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible encryption types. module Type # Encryption type not specified. Defaults to GOOGLE_DEFAULT_ENCRYPTION. TYPE_UNSPECIFIED = 0 # The data is encrypted at rest with a key that is fully managed by Google. # No key version will be populated. This is the default state. GOOGLE_DEFAULT_ENCRYPTION = 1 # The data is encrypted at rest with a key that is managed by the customer. # KMS key versions will be populated. CUSTOMER_MANAGED_ENCRYPTION = 2 end # The state of the KMS key perceived by the system. Refer to the public # documentation for the impact of each state. module KmsKeyState # The default value. This value is unused. KMS_KEY_STATE_UNSPECIFIED = 0 # The KMS key is enabled and correctly configured. ENABLED = 1 # Permission denied on the KMS key. PERMISSION_DENIED = 2 # The KMS key is disabled. DISABLED = 3 # The KMS key is destroyed. DESTROYED = 4 # The KMS key is scheduled to be destroyed. DESTROY_SCHEDULED = 5 # The EKM key is unreachable. EKM_KEY_UNREACHABLE_DETECTED = 6 # Billing is disabled for the project. BILLING_DISABLED = 7 # All other unknown failures. UNKNOWN_FAILURE = 8 end end |
#kms_key_versions ⇒ ::Array<::String> (readonly)
Returns Output only. KMS key versions that are being used to protect the data at-rest.
1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1780 class EncryptionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible encryption types. module Type # Encryption type not specified. Defaults to GOOGLE_DEFAULT_ENCRYPTION. TYPE_UNSPECIFIED = 0 # The data is encrypted at rest with a key that is fully managed by Google. # No key version will be populated. This is the default state. GOOGLE_DEFAULT_ENCRYPTION = 1 # The data is encrypted at rest with a key that is managed by the customer. # KMS key versions will be populated. CUSTOMER_MANAGED_ENCRYPTION = 2 end # The state of the KMS key perceived by the system. Refer to the public # documentation for the impact of each state. module KmsKeyState # The default value. This value is unused. KMS_KEY_STATE_UNSPECIFIED = 0 # The KMS key is enabled and correctly configured. ENABLED = 1 # Permission denied on the KMS key. PERMISSION_DENIED = 2 # The KMS key is disabled. DISABLED = 3 # The KMS key is destroyed. DESTROYED = 4 # The KMS key is scheduled to be destroyed. DESTROY_SCHEDULED = 5 # The EKM key is unreachable. EKM_KEY_UNREACHABLE_DETECTED = 6 # Billing is disabled for the project. BILLING_DISABLED = 7 # All other unknown failures. UNKNOWN_FAILURE = 8 end end |
#last_update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The most recent time when the encryption info was updated.
1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1780 class EncryptionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible encryption types. module Type # Encryption type not specified. Defaults to GOOGLE_DEFAULT_ENCRYPTION. TYPE_UNSPECIFIED = 0 # The data is encrypted at rest with a key that is fully managed by Google. # No key version will be populated. This is the default state. GOOGLE_DEFAULT_ENCRYPTION = 1 # The data is encrypted at rest with a key that is managed by the customer. # KMS key versions will be populated. CUSTOMER_MANAGED_ENCRYPTION = 2 end # The state of the KMS key perceived by the system. Refer to the public # documentation for the impact of each state. module KmsKeyState # The default value. This value is unused. KMS_KEY_STATE_UNSPECIFIED = 0 # The KMS key is enabled and correctly configured. ENABLED = 1 # Permission denied on the KMS key. PERMISSION_DENIED = 2 # The KMS key is disabled. DISABLED = 3 # The KMS key is destroyed. DESTROYED = 4 # The KMS key is scheduled to be destroyed. DESTROY_SCHEDULED = 5 # The EKM key is unreachable. EKM_KEY_UNREACHABLE_DETECTED = 6 # Billing is disabled for the project. BILLING_DISABLED = 7 # All other unknown failures. UNKNOWN_FAILURE = 8 end end |