Class: Google::Cloud::Memorystore::V1::EncryptionInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Memorystore::V1::EncryptionInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/memorystore/v1/memorystore.rb
Overview
EncryptionInfo describes the encryption information of a cluster.
Defined Under Namespace
Modules: KmsKeyState, Type
Instance Attribute Summary collapse
-
#encryption_type ⇒ ::Google::Cloud::Memorystore::V1::EncryptionInfo::Type
readonly
Output only.
-
#kms_key_primary_state ⇒ ::Google::Cloud::Memorystore::V1::EncryptionInfo::KmsKeyState
readonly
Output only.
-
#kms_key_versions ⇒ ::Array<::String>
readonly
Output only.
-
#last_update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#encryption_type ⇒ ::Google::Cloud::Memorystore::V1::EncryptionInfo::Type (readonly)
Returns Output only. Type of encryption.
1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1531 class EncryptionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible encryption types. module Type # Encryption type not specified. Defaults to GOOGLE_DEFAULT_ENCRYPTION. TYPE_UNSPECIFIED = 0 # The data is encrypted at rest with a key that is fully managed by Google. # No key version will be populated. This is the default state. GOOGLE_DEFAULT_ENCRYPTION = 1 # The data is encrypted at rest with a key that is managed by the customer. # KMS key versions will be populated. CUSTOMER_MANAGED_ENCRYPTION = 2 end # The state of the KMS key perceived by the system. Refer to the public # documentation for the impact of each state. module KmsKeyState # The default value. This value is unused. KMS_KEY_STATE_UNSPECIFIED = 0 # The KMS key is enabled and correctly configured. ENABLED = 1 # Permission denied on the KMS key. PERMISSION_DENIED = 2 # The KMS key is disabled. DISABLED = 3 # The KMS key is destroyed. DESTROYED = 4 # The KMS key is scheduled to be destroyed. DESTROY_SCHEDULED = 5 # The EKM key is unreachable. EKM_KEY_UNREACHABLE_DETECTED = 6 # Billing is disabled for the project. BILLING_DISABLED = 7 # All other unknown failures. UNKNOWN_FAILURE = 8 end end |
#kms_key_primary_state ⇒ ::Google::Cloud::Memorystore::V1::EncryptionInfo::KmsKeyState (readonly)
Returns Output only. The state of the primary version of the KMS key perceived by the system. This field is not populated in backups.
1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1531 class EncryptionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible encryption types. module Type # Encryption type not specified. Defaults to GOOGLE_DEFAULT_ENCRYPTION. TYPE_UNSPECIFIED = 0 # The data is encrypted at rest with a key that is fully managed by Google. # No key version will be populated. This is the default state. GOOGLE_DEFAULT_ENCRYPTION = 1 # The data is encrypted at rest with a key that is managed by the customer. # KMS key versions will be populated. CUSTOMER_MANAGED_ENCRYPTION = 2 end # The state of the KMS key perceived by the system. Refer to the public # documentation for the impact of each state. module KmsKeyState # The default value. This value is unused. KMS_KEY_STATE_UNSPECIFIED = 0 # The KMS key is enabled and correctly configured. ENABLED = 1 # Permission denied on the KMS key. PERMISSION_DENIED = 2 # The KMS key is disabled. DISABLED = 3 # The KMS key is destroyed. DESTROYED = 4 # The KMS key is scheduled to be destroyed. DESTROY_SCHEDULED = 5 # The EKM key is unreachable. EKM_KEY_UNREACHABLE_DETECTED = 6 # Billing is disabled for the project. BILLING_DISABLED = 7 # All other unknown failures. UNKNOWN_FAILURE = 8 end end |
#kms_key_versions ⇒ ::Array<::String> (readonly)
Returns Output only. KMS key versions that are being used to protect the data at-rest.
1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1531 class EncryptionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible encryption types. module Type # Encryption type not specified. Defaults to GOOGLE_DEFAULT_ENCRYPTION. TYPE_UNSPECIFIED = 0 # The data is encrypted at rest with a key that is fully managed by Google. # No key version will be populated. This is the default state. GOOGLE_DEFAULT_ENCRYPTION = 1 # The data is encrypted at rest with a key that is managed by the customer. # KMS key versions will be populated. CUSTOMER_MANAGED_ENCRYPTION = 2 end # The state of the KMS key perceived by the system. Refer to the public # documentation for the impact of each state. module KmsKeyState # The default value. This value is unused. KMS_KEY_STATE_UNSPECIFIED = 0 # The KMS key is enabled and correctly configured. ENABLED = 1 # Permission denied on the KMS key. PERMISSION_DENIED = 2 # The KMS key is disabled. DISABLED = 3 # The KMS key is destroyed. DESTROYED = 4 # The KMS key is scheduled to be destroyed. DESTROY_SCHEDULED = 5 # The EKM key is unreachable. EKM_KEY_UNREACHABLE_DETECTED = 6 # Billing is disabled for the project. BILLING_DISABLED = 7 # All other unknown failures. UNKNOWN_FAILURE = 8 end end |
#last_update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The most recent time when the encryption info was updated.
1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1531 class EncryptionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible encryption types. module Type # Encryption type not specified. Defaults to GOOGLE_DEFAULT_ENCRYPTION. TYPE_UNSPECIFIED = 0 # The data is encrypted at rest with a key that is fully managed by Google. # No key version will be populated. This is the default state. GOOGLE_DEFAULT_ENCRYPTION = 1 # The data is encrypted at rest with a key that is managed by the customer. # KMS key versions will be populated. CUSTOMER_MANAGED_ENCRYPTION = 2 end # The state of the KMS key perceived by the system. Refer to the public # documentation for the impact of each state. module KmsKeyState # The default value. This value is unused. KMS_KEY_STATE_UNSPECIFIED = 0 # The KMS key is enabled and correctly configured. ENABLED = 1 # Permission denied on the KMS key. PERMISSION_DENIED = 2 # The KMS key is disabled. DISABLED = 3 # The KMS key is destroyed. DESTROYED = 4 # The KMS key is scheduled to be destroyed. DESTROY_SCHEDULED = 5 # The EKM key is unreachable. EKM_KEY_UNREACHABLE_DETECTED = 6 # Billing is disabled for the project. BILLING_DISABLED = 7 # All other unknown failures. UNKNOWN_FAILURE = 8 end end |