Class: Google::Cloud::Memorystore::V1::EncryptionInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1/memorystore.rb

Overview

EncryptionInfo describes the encryption information of a cluster.

Defined Under Namespace

Modules: KmsKeyState, Type

Instance Attribute Summary collapse

Instance Attribute Details

#encryption_type::Google::Cloud::Memorystore::V1::EncryptionInfo::Type (readonly)

Returns Output only. Type of encryption.

Returns:



1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1425

class EncryptionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible encryption types.
  module Type
    # Encryption type not specified. Defaults to GOOGLE_DEFAULT_ENCRYPTION.
    TYPE_UNSPECIFIED = 0

    # The data is encrypted at rest with a key that is fully managed by Google.
    # No key version will be populated. This is the default state.
    GOOGLE_DEFAULT_ENCRYPTION = 1

    # The data is encrypted at rest with a key that is managed by the customer.
    # KMS key versions will be populated.
    CUSTOMER_MANAGED_ENCRYPTION = 2
  end

  # The state of the KMS key perceived by the system. Refer to the public
  # documentation for the impact of each state.
  module KmsKeyState
    # The default value. This value is unused.
    KMS_KEY_STATE_UNSPECIFIED = 0

    # The KMS key is enabled and correctly configured.
    ENABLED = 1

    # Permission denied on the KMS key.
    PERMISSION_DENIED = 2

    # The KMS key is disabled.
    DISABLED = 3

    # The KMS key is destroyed.
    DESTROYED = 4

    # The KMS key is scheduled to be destroyed.
    DESTROY_SCHEDULED = 5

    # The EKM key is unreachable.
    EKM_KEY_UNREACHABLE_DETECTED = 6

    # Billing is disabled for the project.
    BILLING_DISABLED = 7

    # All other unknown failures.
    UNKNOWN_FAILURE = 8
  end
end

#kms_key_primary_state::Google::Cloud::Memorystore::V1::EncryptionInfo::KmsKeyState (readonly)

Returns Output only. The state of the primary version of the KMS key perceived by the system. This field is not populated in backups.

Returns:



1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1425

class EncryptionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible encryption types.
  module Type
    # Encryption type not specified. Defaults to GOOGLE_DEFAULT_ENCRYPTION.
    TYPE_UNSPECIFIED = 0

    # The data is encrypted at rest with a key that is fully managed by Google.
    # No key version will be populated. This is the default state.
    GOOGLE_DEFAULT_ENCRYPTION = 1

    # The data is encrypted at rest with a key that is managed by the customer.
    # KMS key versions will be populated.
    CUSTOMER_MANAGED_ENCRYPTION = 2
  end

  # The state of the KMS key perceived by the system. Refer to the public
  # documentation for the impact of each state.
  module KmsKeyState
    # The default value. This value is unused.
    KMS_KEY_STATE_UNSPECIFIED = 0

    # The KMS key is enabled and correctly configured.
    ENABLED = 1

    # Permission denied on the KMS key.
    PERMISSION_DENIED = 2

    # The KMS key is disabled.
    DISABLED = 3

    # The KMS key is destroyed.
    DESTROYED = 4

    # The KMS key is scheduled to be destroyed.
    DESTROY_SCHEDULED = 5

    # The EKM key is unreachable.
    EKM_KEY_UNREACHABLE_DETECTED = 6

    # Billing is disabled for the project.
    BILLING_DISABLED = 7

    # All other unknown failures.
    UNKNOWN_FAILURE = 8
  end
end

#kms_key_versions::Array<::String> (readonly)

Returns Output only. KMS key versions that are being used to protect the data at-rest.

Returns:

  • (::Array<::String>)

    Output only. KMS key versions that are being used to protect the data at-rest.



1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1425

class EncryptionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible encryption types.
  module Type
    # Encryption type not specified. Defaults to GOOGLE_DEFAULT_ENCRYPTION.
    TYPE_UNSPECIFIED = 0

    # The data is encrypted at rest with a key that is fully managed by Google.
    # No key version will be populated. This is the default state.
    GOOGLE_DEFAULT_ENCRYPTION = 1

    # The data is encrypted at rest with a key that is managed by the customer.
    # KMS key versions will be populated.
    CUSTOMER_MANAGED_ENCRYPTION = 2
  end

  # The state of the KMS key perceived by the system. Refer to the public
  # documentation for the impact of each state.
  module KmsKeyState
    # The default value. This value is unused.
    KMS_KEY_STATE_UNSPECIFIED = 0

    # The KMS key is enabled and correctly configured.
    ENABLED = 1

    # Permission denied on the KMS key.
    PERMISSION_DENIED = 2

    # The KMS key is disabled.
    DISABLED = 3

    # The KMS key is destroyed.
    DESTROYED = 4

    # The KMS key is scheduled to be destroyed.
    DESTROY_SCHEDULED = 5

    # The EKM key is unreachable.
    EKM_KEY_UNREACHABLE_DETECTED = 6

    # Billing is disabled for the project.
    BILLING_DISABLED = 7

    # All other unknown failures.
    UNKNOWN_FAILURE = 8
  end
end

#last_update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The most recent time when the encryption info was updated.

Returns:



1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1425

class EncryptionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible encryption types.
  module Type
    # Encryption type not specified. Defaults to GOOGLE_DEFAULT_ENCRYPTION.
    TYPE_UNSPECIFIED = 0

    # The data is encrypted at rest with a key that is fully managed by Google.
    # No key version will be populated. This is the default state.
    GOOGLE_DEFAULT_ENCRYPTION = 1

    # The data is encrypted at rest with a key that is managed by the customer.
    # KMS key versions will be populated.
    CUSTOMER_MANAGED_ENCRYPTION = 2
  end

  # The state of the KMS key perceived by the system. Refer to the public
  # documentation for the impact of each state.
  module KmsKeyState
    # The default value. This value is unused.
    KMS_KEY_STATE_UNSPECIFIED = 0

    # The KMS key is enabled and correctly configured.
    ENABLED = 1

    # Permission denied on the KMS key.
    PERMISSION_DENIED = 2

    # The KMS key is disabled.
    DISABLED = 3

    # The KMS key is destroyed.
    DESTROYED = 4

    # The KMS key is scheduled to be destroyed.
    DESTROY_SCHEDULED = 5

    # The EKM key is unreachable.
    EKM_KEY_UNREACHABLE_DETECTED = 6

    # Billing is disabled for the project.
    BILLING_DISABLED = 7

    # All other unknown failures.
    UNKNOWN_FAILURE = 8
  end
end