Class: Google::Cloud::Memorystore::V1::PersistenceConfig::RDBConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Memorystore::V1::PersistenceConfig::RDBConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/memorystore/v1/memorystore.rb
Overview
Configuration for RDB based persistence.
Defined Under Namespace
Modules: SnapshotPeriod
Instance Attribute Summary collapse
-
#rdb_snapshot_period ⇒ ::Google::Cloud::Memorystore::V1::PersistenceConfig::RDBConfig::SnapshotPeriod
Optional.
-
#rdb_snapshot_start_time ⇒ ::Google::Protobuf::Timestamp
Optional.
Instance Attribute Details
#rdb_snapshot_period ⇒ ::Google::Cloud::Memorystore::V1::PersistenceConfig::RDBConfig::SnapshotPeriod
Returns Optional. Period between RDB snapshots.
967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 967 class RDBConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible snapshot periods. module SnapshotPeriod # Not set. SNAPSHOT_PERIOD_UNSPECIFIED = 0 # One hour. ONE_HOUR = 1 # Six hours. SIX_HOURS = 2 # Twelve hours. TWELVE_HOURS = 3 # Twenty four hours. TWENTY_FOUR_HOURS = 4 end end |
#rdb_snapshot_start_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. Time that the first snapshot was/will be attempted, and to which future snapshots will be aligned. If not provided, the current time will be used.
967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 967 class RDBConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible snapshot periods. module SnapshotPeriod # Not set. SNAPSHOT_PERIOD_UNSPECIFIED = 0 # One hour. ONE_HOUR = 1 # Six hours. SIX_HOURS = 2 # Twelve hours. TWELVE_HOURS = 3 # Twenty four hours. TWENTY_FOUR_HOURS = 4 end end |