Class: Google::Cloud::Memorystore::V1::SelfManagedSource
- Inherits:
-
Object
- Object
- Google::Cloud::Memorystore::V1::SelfManagedSource
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/memorystore/v1/memorystore.rb
Overview
Details of the self-managed source instance.
Instance Attribute Summary collapse
-
#ip_address ⇒ ::String
Required.
-
#network_attachment ⇒ ::String
Required.
-
#port ⇒ ::Integer
Required.
Instance Attribute Details
#ip_address ⇒ ::String
Returns Required. The IP address of the source instance. This IP address should be a stable IP address that can be accessed by the Memorystore instance throughout the migration process.
470 471 472 473 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 470 class SelfManagedSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#network_attachment ⇒ ::String
Returns Required. The resource name of the Private Service Connect Network Attachment used to establish connectivity to the source instance. This network attachment has the following requirements:
- It must be in the same project as the Memorystore instance.
- It must be in the same region as the Memorystore instance.
- The subnet attached to the network attachment must be in the same VPC network as the source instance nodes.
Format: projects/{project}/regions/{region}/networkAttachments/{network_attachment}.
470 471 472 473 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 470 class SelfManagedSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#port ⇒ ::Integer
Returns Required. The port of the source instance. This port should be a stable port that can be accessed by the Memorystore instance throughout the migration process.
470 471 472 473 |
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 470 class SelfManagedSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |