Class: Google::Cloud::Memorystore::V1::SharedRegionalCertificateAuthority

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1/memorystore.rb

Overview

Shared regional certificate authority for an instance.

Defined Under Namespace

Classes: RegionalManagedCertificateAuthority

Instance Attribute Summary collapse

Instance Attribute Details

#managed_server_ca::Google::Cloud::Memorystore::V1::SharedRegionalCertificateAuthority::RegionalManagedCertificateAuthority

Returns CA certificate chains for memorystore managed server authentication.

Returns:



1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1450

class SharedRegionalCertificateAuthority
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CA certificate chains for memorystore managed server authentication.
  # @!attribute [rw] ca_certs
  #   @return [::Array<::Google::Cloud::Memorystore::V1::SharedRegionalCertificateAuthority::RegionalManagedCertificateAuthority::RegionalCertChain>]
  #     The PEM encoded CA certificate chains for memorystore managed
  #     server authentication
  class RegionalManagedCertificateAuthority
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The certificates that form the CA chain, from leaf to root order.
    # @!attribute [rw] certificates
    #   @return [::Array<::String>]
    #     The certificates that form the CA chain, from leaf to root order.
    class RegionalCertChain
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#name::String

Returns Identifier. Unique name of the resource in this scope including project and location using the form: projects/{project}/locations/{location}/sharedRegionalCertificateAuthority.

Returns:

  • (::String)

    Identifier. Unique name of the resource in this scope including project and location using the form: projects/{project}/locations/{location}/sharedRegionalCertificateAuthority



1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1450

class SharedRegionalCertificateAuthority
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CA certificate chains for memorystore managed server authentication.
  # @!attribute [rw] ca_certs
  #   @return [::Array<::Google::Cloud::Memorystore::V1::SharedRegionalCertificateAuthority::RegionalManagedCertificateAuthority::RegionalCertChain>]
  #     The PEM encoded CA certificate chains for memorystore managed
  #     server authentication
  class RegionalManagedCertificateAuthority
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The certificates that form the CA chain, from leaf to root order.
    # @!attribute [rw] certificates
    #   @return [::Array<::String>]
    #     The certificates that form the CA chain, from leaf to root order.
    class RegionalCertChain
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end