Class: Google::Cloud::Memorystore::V1::SharedRegionalCertificateAuthority

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1/memorystore.rb

Overview

Shared regional certificate authority for an instance.

Defined Under Namespace

Classes: RegionalManagedCertificateAuthority

Instance Attribute Summary collapse

Instance Attribute Details

#managed_server_ca::Google::Cloud::Memorystore::V1::SharedRegionalCertificateAuthority::RegionalManagedCertificateAuthority

Returns CA certificate chains for memorystore managed server authentication.

Returns:



1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1343

class SharedRegionalCertificateAuthority
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CA certificate chains for memorystore managed server authentication.
  # @!attribute [rw] ca_certs
  #   @return [::Array<::Google::Cloud::Memorystore::V1::SharedRegionalCertificateAuthority::RegionalManagedCertificateAuthority::RegionalCertChain>]
  #     The PEM encoded CA certificate chains for memorystore managed
  #     server authentication
  class RegionalManagedCertificateAuthority
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The certificates that form the CA chain, from leaf to root order.
    # @!attribute [rw] certificates
    #   @return [::Array<::String>]
    #     The certificates that form the CA chain, from leaf to root order.
    class RegionalCertChain
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#name::String

Returns Identifier. Unique name of the resource in this scope including project and location using the form: projects/{project}/locations/{location}/sharedRegionalCertificateAuthority.

Returns:

  • (::String)

    Identifier. Unique name of the resource in this scope including project and location using the form: projects/{project}/locations/{location}/sharedRegionalCertificateAuthority



1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
# File 'proto_docs/google/cloud/memorystore/v1/memorystore.rb', line 1343

class SharedRegionalCertificateAuthority
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CA certificate chains for memorystore managed server authentication.
  # @!attribute [rw] ca_certs
  #   @return [::Array<::Google::Cloud::Memorystore::V1::SharedRegionalCertificateAuthority::RegionalManagedCertificateAuthority::RegionalCertChain>]
  #     The PEM encoded CA certificate chains for memorystore managed
  #     server authentication
  class RegionalManagedCertificateAuthority
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The certificates that form the CA chain, from leaf to root order.
    # @!attribute [rw] certificates
    #   @return [::Array<::String>]
    #     The certificates that form the CA chain, from leaf to root order.
    class RegionalCertChain
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end